pub struct NullVec<T, const LEN: usize>(_);
A zero sized struct that implements StaticVec. It will always panic when trying to access any data within it. You should generally never have to use this struct, it is only here to avoid performance loss in some cases where functions might expect an argument that ypu know will never be used.

use slas::prelude::*;

unsafe{ NullVec::<f32, 10>::new() };

Implementations